#!/usr/bin/env node
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _subcommander = require('subcommander');

var _subcommander2 = _interopRequireDefault(_subcommander);

var _childProcessPromise = require('child-process-promise');

var _package = require('../package.json');

var _build = require('./build');

var _build2 = _interopRequireDefault(_build);

var _bundle = require('./bundle');

var _bundle2 = _interopRequireDefault(_bundle);

var _dev = require('./dev');

var _dev2 = _interopRequireDefault(_dev);

var _serve = require('./serve');

var _serve2 = _interopRequireDefault(_serve);

var _run = require('./run');

var _run2 = _interopRequireDefault(_run);

var _rename = require('./rename');

var _rename2 = _interopRequireDefault(_rename);

var _reset = require('./reset');

var _reset2 = _interopRequireDefault(_reset);

var _tests = require('./tests');

var _tests2 = _interopRequireDefault(_tests);

var _copyConfig = require('./babel/copy-config');

var _copyConfig2 = _interopRequireDefault(_copyConfig);

var _copyConfig3 = require('./postcss/copy-config');

var _copyConfig4 = _interopRequireDefault(_copyConfig3);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_subcommander2.default.command('version', {
	desc: 'Display ' + _package.name + ' version',
	callback: function callback() {
		return console.log(_package.version);
	}
});

_subcommander2.default.command('build', {
	desc: 'Build distributable files',
	callback: _build2.default
}).option('src', {
	default: 'src',
	desc: 'The source directory of your project'
}).option('dist', {
	desc: 'The distribution directory your project will compile to'
}).option('no-config', {
	desc: 'Don\'t copy config files',
	flag: true
});

_subcommander2.default.command('bundle', {
	desc: 'Build distributable bundle',
	callback: _bundle2.default
}).option('src', {
	default: 'src',
	desc: 'The source file of your project'
}).option('dist', {
	desc: 'The distribution file/directory your project will compile to'
}).option('no-config', {
	desc: 'Don\'t copy config files',
	flag: true
}).option('global', {
	desc: 'Export a global window variable'
});

_subcommander2.default.command('dev', {
	desc: 'Live develop in browser',
	callback: _dev2.default
}).option('src', {
	desc: 'The source directory or file of your project'
}).option('dist', {
	desc: 'The distribution directory of your project'
}).option('no-hmr', {
	desc: 'Disable hot module reloading',
	flag: true
}).option('no-config', {
	desc: 'Don\'t copy config files',
	flag: true
});

_subcommander2.default.command('serve', {
	desc: 'Serve a directory of static files',
	callback: _serve2.default
}).option('src', {
	desc: 'The directory to serve',
	default: 'dist'
}).option('no-open', {
	desc: 'Prevents browser from opening',
	flag: true
});

_subcommander2.default.command('run', {
	desc: 'Run a file in Node.js',
	callback: _run2.default
}).option('file', {
	desc: 'The file to run',
	default: './src/index'
}).option('no-config', {
	desc: 'Don\'t copy config files',
	flag: true
});

_subcommander2.default.command('rename', {
	desc: 'Renames project files',
	callback: _rename2.default
}).option('name', {
	desc: 'The new name'
});

_subcommander2.default.command('reset', {
	desc: 'Resets and renames project',
	callback: _reset2.default
}).option('name', {
	desc: 'The new name'
});

_subcommander2.default.command('test', {
	desc: 'Runs tests',
	callback: _tests2.default
}).option('no-config', {
	desc: 'Don\'t copy config files',
	flag: true
});

var config = _subcommander2.default.command('config', {
	desc: 'Copy config files'
});
config.command('babel', {
	desc: 'Copy Babel config',
	callback: _copyConfig2.default
});
config.command('postcss', {
	desc: 'Copy PostCSS config',
	callback: _copyConfig4.default
});
config.command('all', {
	desc: 'Copy all configs',
	callback: function () {
		var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(options) {
			return _regenerator2.default.wrap(function _callee$(_context) {
				while (1) {
					switch (_context.prev = _context.next) {
						case 0:
							_context.next = 2;
							return Promise.all([(0, _copyConfig2.default)(options), (0, _copyConfig4.default)(options)]);

						case 2:
						case 'end':
							return _context.stop();
					}
				}
			}, _callee, undefined);
		}));

		return function callback(_x) {
			return _ref.apply(this, arguments);
		};
	}()
});

_subcommander2.default.parse();
//# sourceMappingURL=index.js.map